==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/da-DK/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekræft massefortegnelser',
    'bulk_restore'      => 'Bekræft Massegendannelsesaktiver', 
  'bulk_delete_help'	=> 'Gennemgå aktiver for massesletning nedenfor. Disse aktiver kan gendannes når slettet, men de vil ikke længere være forbundet med eventuelle brugere, de i øjeblikket er tildelt.',
  'bulk_restore_help'	=> 'Gennemgå aktiverne til bulk-restaurering nedenfor. Når genoprettet, vil disse aktiver ikke være forbundet med nogen brugere, de tidligere var tildelt.',
  'bulk_delete_warn'	=> 'Du er i gang med at slette :asset_count aktiver.',
  'bulk_restore_warn'	=> 'Du er ved at gendanne :asset_count aktiver.',
    'bulk_update'		=> 'Masseopdater Aktiver',
    'bulk_update_help'	=> 'Denne form tillader dig at opdatere flere aktiver på en gang. Udfyld kun de felter der skal ændres. Ikke udfyldte feltet forbilver uændret.',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for et enkelt aktiv, og du er ved at redigere egenskaberne for :asset_count aktiver.',
    'bulk_update_with_custom_field' => 'Bemærk at aktiverne er :asset_model_count forskellige typer af modeller.',
    'bulk_update_model_prefix' => 'Til Modeller', 
    'bulk_update_custom_field_unique' => 'Dette er et unikt felt og kan ikke masseredigeres.',
    'checkedout_to'		=> 'Tjekket Ud Til',
    'checkout_date'		=> 'Tjekket Ud Dato',
    'checkin_date'		=> 'Tjekket Ind Dato',
    'checkout_to'		=> 'Tjekket ud til',
    'cost'				=> 'Indkøbspris',
    'create'			=> 'Opret Aktiv',
    'date'				=> 'Købsdato',
    'depreciation'	    => 'Afskrivninger',
    'depreciates_on'	=> 'Afskrives Den',
    'default_location'	=> 'Standardplacering',
    'default_location_phone' => 'Standard Lokationstelefon',
    'eol_date'			=> 'EOL Dato',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Forventet indtjekningsdato',
    'expires'			=> 'Udløber',
    'fully_depreciated'	=> 'Fuldt Afskrevet',
    'help_checkout'		=> 'Vælg "Klar til implementering" fra listen ovenfor, hvis du ønsker at tildele dette aktiv med det samme. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'måneder',
    'name'				=> 'Aktivnavn',
    'notes'				=> 'Noter',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR kode',
    'requestable'		=> 'Brugere kan efterspørge dette aktiv',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Vælg statustype',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Aktiv mærkat',
    'update'			=> 'Aktiv Opdatering',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantiudløb',
    'years'				=> 'år',
    'asset_location' => 'Opdater Aktiv Placering',
    'asset_location_update_default_current' => 'Opdater standardplacering OG faktisk placering',
    'asset_location_update_default' => 'Opdater kun standardplacering',
    'asset_location_update_actual' => 'Opdater kun den faktiske placering',
    'asset_not_deployable' => 'Denne aktivstatus er ikke implementerbar. Dette aktiv kan ikke tjekkes ud.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Denne status er anvendelig. Dette aktiv kan tjekkes ud.',
    'processing_spinner' => 'Behandler... (Dette kan tage lidt tid på store filer)',
    'optional_infos'  => 'Valgfri Information',
    'order_details'   => 'Ordre Relateret Information',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/da-DK/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekræft massefortegnelser',
    'bulk_restore'      => 'Bekræft Massegendannelsesaktiver', 
  'bulk_delete_help'	=> 'Gennemgå aktiver for massesletning nedenfor. Disse aktiver kan gendannes når slettet, men de vil ikke længere være forbundet med eventuelle brugere, de i øjeblikket er tildelt.',
  'bulk_restore_help'	=> 'Gennemgå aktiverne til bulk-restaurering nedenfor. Når genoprettet, vil disse aktiver ikke være forbundet med nogen brugere, de tidligere var tildelt.',
  'bulk_delete_warn'	=> 'Du er i gang med at slette :asset_count aktiver.',
  'bulk_restore_warn'	=> 'Du er ved at gendanne :asset_count aktiver.',
    'bulk_update'		=> 'Masseopdater Aktiver',
    'bulk_update_help'	=> 'Denne form tillader dig at opdatere flere aktiver på en gang. Udfyld kun de felter der skal ændres. Ikke udfyldte feltet forbilver uændret.',
    'bulk_update_warn'	=> 'Du er ved at redigere egenskaberne for et enkelt aktiv, og du er ved at redigere egenskaberne for :asset_count aktiver.',
    'bulk_update_with_custom_field' => 'Bemærk at aktiverne er :asset_model_count forskellige typer af modeller.',
    'bulk_update_model_prefix' => 'Til Modeller', 
    'bulk_update_custom_field_unique' => 'Dette er et unikt felt og kan ikke masseredigeres.',
    'checkedout_to'		=> 'Tjekket Ud Til',
    'checkout_date'		=> 'Tjekket Ud Dato',
    'checkin_date'		=> 'Tjekket Ind Dato',
    'checkout_to'		=> 'Tjekket ud til',
    'cost'				=> 'Indkøbspris',
    'create'			=> 'Opret Aktiv',
    'date'				=> 'Købsdato',
    'depreciation'	    => 'Afskrivninger',
    'depreciates_on'	=> 'Afskrives Den',
    'default_location'	=> 'Standardplacering',
    'default_location_phone' => 'Standard Lokationstelefon',
    'eol_date'			=> 'EOL Dato',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Forventet indtjekningsdato',
    'expires'			=> 'Udløber',
    'fully_depreciated'	=> 'Fuldt Afskrevet',
    'help_checkout'		=> 'Vælg "Klar til implementering" fra listen ovenfor, hvis du ønsker at tildele dette aktiv med det samme. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'måneder',
    'name'				=> 'Aktivnavn',
    'notes'				=> 'Noter',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR kode',
    'requestable'		=> 'Brugere kan efterspørge dette aktiv',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Vælg statustype',
    'serial'			=> 'Serienummer',
    'serial_required'	=> 'Asset :number requires a serial number',
    'serial_required_post_model_update'	=> ':asset_model have been updated to require a serial number. Please add a serial number for this asset.',
    'status'			=> 'Status',
    'tag'				=> 'Aktiv mærkat',
    'update'			=> 'Aktiv Opdatering',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantiudløb',
    'years'				=> 'år',
    'asset_location' => 'Opdater Aktiv Placering',
    'asset_location_update_default_current' => 'Opdater standardplacering OG faktisk placering',
    'asset_location_update_default' => 'Opdater kun standardplacering',
    'asset_location_update_actual' => 'Opdater kun den faktiske placering',
    'asset_not_deployable' => 'Denne aktivstatus er ikke implementerbar. Dette aktiv kan ikke tjekkes ud.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'This asset can be checked out.',
    'processing_spinner' => 'Behandler... (Dette kan tage lidt tid på store filer)',
    'processing' => 'Processing... ',
    'optional_infos'  => 'Valgfri Information',
    'order_details'   => 'Ordre Relateret Information',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
